@@ -1,7 +1,7 @@
 package Data::Clean::JSON;
 
-our $DATE = '2015-06-08'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-06-10'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -42,7 +42,7 @@ Data::Clean::JSON - Clean data so it is safe to output to JSON
 
 =head1 VERSION
 
-This document describes version 0.27 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2015-06-08.
+This document describes version 0.28 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2015-06-10.
 
 =head1 SYNOPSIS
 
@@ -172,6 +172,13 @@ L<Data::Rmap>
 
 L<Data::Visitor::Callback>
 
+L<Data::Abridge> is similar in goal, which is to let Perl data structures (which
+might contain stuffs unsupported in JSON) be encodeable to JSON. But unlike
+Data::Clean::JSON, it has some (currently) non-configurable rules, like changing
+a coderef with a hash C<< {CODE=>'\&main::__ANON__'} >> or a scalar ref with C<<
+{SCALAR=>'value'} >> and so on. Note that the abridging process is similarly
+unidirectional (you cannot convert back the original Perl data structure).
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Clean-JSON>.
